@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* Evolution calendar - iCalendar http backend
  *
- * Copyright (C) 2003 Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Authors: Hans Petter Jansson <hpj@ximian.com>
  *
@@ -25,8 +25,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <gconf/gconf-client.h>
-#include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-moniker-util.h>
 #include <glib/gi18n-lib.h>
 #include "libedataserver/e-xml-hash-utils.h"
 #include <libecal/e-cal-recur.h>
@@ -243,6 +241,7 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 	icalcomponent *icalcomp, *subcomp;
 	icalcomponent_kind kind;
 	const char *newuri;
+	SoupURI *uri_parsed;
 	GHashTable *old_cache;
 	GList *comps_in_cache;
 
@@ -256,9 +255,22 @@ retrieval_done (SoupSession *session, SoupMessage *msg, ECalBackendHttp *cbhttp)
 		newuri = soup_message_headers_get (msg->response_headers,
 						   "Location");
 
-		d(g_message ("Redirected to %s\n", newuri));
+		d(g_message ("Redirected from %s to %s\n", priv->uri, newuri));
 
 		if (newuri) {
+			if (newuri[0]=='/') {
+				g_warning ("Hey! Relative URI returned! Working around...\n");
+
+				uri_parsed = soup_uri_new (priv->uri);
+				soup_uri_set_path (uri_parsed, newuri);
+				soup_uri_set_query (uri_parsed, NULL);
+				// g_free(newuri);
+
+				newuri = soup_uri_to_string (uri_parsed, FALSE);
+				g_message ("Translated URI: %s\n", newuri);
+				soup_uri_free (uri_parsed);
+			}
+
 			g_free (priv->uri);
 
 			priv->uri = webcal_to_http_method (newuri, FALSE);
@@ -485,6 +497,11 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 
 	/* create message to be sent to server */
 	soup_message = soup_message_new (SOUP_METHOD_GET, priv->uri);
+	if (!soup_message) {
+		g_critical ("Cannot fetch the webcal!\n");
+		return TRUE;
+	}
+
 	soup_message_headers_append (soup_message->request_headers, "User-Agent",
 				     "Evolution/" VERSION);
 	soup_message_set_flags (soup_message, SOUP_MESSAGE_NO_REDIRECT);
@@ -563,7 +580,22 @@ e_cal_backend_http_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_
 	}
 
 	if (!priv->cache) {
-		priv->cache = e_cal_backend_cache_new (e_cal_backend_get_uri (E_CAL_BACKEND (backend)), e_cal_backend_get_kind (E_CAL_BACKEND (backend)));
+		ECalSourceType source_type;
+
+		switch (e_cal_backend_get_kind (E_CAL_BACKEND (backend))) {
+			default:
+			case ICAL_VEVENT_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_EVENT;
+				break;
+			case ICAL_VTODO_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_TODO;
+				break;
+			case ICAL_VJOURNAL_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_JOURNAL;
+				break;
+		}
+
+		priv->cache = e_cal_backend_cache_new (e_cal_backend_get_uri (E_CAL_BACKEND (backend)), source_type);
 
 		if (!priv->cache) {
 			e_cal_backend_notify_error (E_CAL_BACKEND(cbhttp), _("Could not create cache file"));
