@@ -93,6 +93,9 @@ static CamelMimeMessage *groupwise_folder_item_to_msg ( CamelFolder *folder, EGw
 
 #define d(x)  
 
+const char * GET_ITEM_VIEW_WITH_CACHE = "peek default recipient threading attachments subject status priority startDate created delivered size recurrenceKey message notification";
+const char * GET_ITEM_VIEW_WITHOUT_CACHE = "peek default recipient threading hasAttachment subject status priority startDate created delivered size recurrenceKey";
+
 static CamelMimeMessage *
 groupwise_folder_get_message( CamelFolder *folder, const char *uid, CamelException *ex )
 {
@@ -166,7 +169,7 @@ groupwise_folder_get_message( CamelFolder *folder, const char *uid, CamelExcepti
 
 	cnc = cnc_lookup (priv);
 	
-	status = e_gw_connection_get_item (cnc, container_id, uid, "peek default distribution recipient message attachments subject notification created recipientStatus status hasAttachment size recurrenceKey", &item);
+	status = e_gw_connection_get_item (cnc, container_id, uid, GET_ITEM_VIEW_WITH_CACHE, &item);
 	if (status != E_GW_CONNECTION_STATUS_OK) {
 		g_free (container_id);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_INVALID, _("Could not get message"));
@@ -183,8 +186,11 @@ groupwise_folder_get_message( CamelFolder *folder, const char *uid, CamelExcepti
 		return NULL;
 	}
 
-	if (msg)
+	if (msg) {
 		camel_medium_set_header (CAMEL_MEDIUM (msg), "X-Evolution-Source", groupwise_base_url_lookup (priv));
+		mi->info.dirty = TRUE;
+		camel_folder_summary_touch (folder->summary);
+	}
 
 	/* add to cache */
 	CAMEL_GROUPWISE_FOLDER_REC_LOCK (folder, cache_lock);
@@ -223,8 +229,11 @@ groupwise_populate_details_from_item (CamelMimeMessage *msg, EGwItem *item)
 		time_t actual_time;
 		int offset = 0;
 		dtstring = e_gw_item_get_creation_date (item);
-		time = e_gw_connection_get_date_from_string (dtstring);
-		actual_time = camel_header_decode_date (ctime(&time), NULL);
+		if (dtstring) {
+				time = e_gw_connection_get_date_from_string (dtstring);
+				actual_time = camel_header_decode_date (ctime(&time), NULL);
+		} else
+				actual_time = (time_t) 0;
 		camel_mime_message_set_date (msg, actual_time, offset);
 	}
 }
@@ -517,6 +526,7 @@ static void
 update_junk_list (CamelStore *store, CamelMessageInfo *info, int flag)
 {
 	gchar **email = NULL, *from = NULL;	
+	int index = 0;
 	CamelGroupwiseStore *gw_store= CAMEL_GROUPWISE_STORE(store);
 	CamelGroupwiseStorePrivate  *priv = gw_store->priv;
 	EGwConnection *cnc = cnc_lookup (priv);
@@ -526,18 +536,25 @@ update_junk_list (CamelStore *store, CamelMessageInfo *info, int flag)
 
 	email = g_strsplit_set (from, "<>", -1);
 
-	if (!email || !email[1])
+	if (from [0] == '<') {
+		/* g_strsplit_set will add a dummy empty string as the first string if the first character in the 
+		original string is one of the delimiters that you want to suppress. 
+		Refer to g_strsplit_set documentation */
+		index = 1;
+	}
+
+	if (!email || !email[index])
 		goto error;
 
 	if (flag == ADD_JUNK_ENTRY)
-		e_gw_connection_create_junk_entry (cnc, email[1], "email", "junk");
+		e_gw_connection_create_junk_entry (cnc, email[index], "email", "junk");
 	else if (flag == REMOVE_JUNK_ENTRY) {
 		GList *list = NULL;
 		EGwJunkEntry *entry;
 		if (e_gw_connection_get_junk_entries (cnc, &list)== E_GW_CONNECTION_STATUS_OK){
 			while (list) {
 				entry = list->data;
-				if (!g_ascii_strcasecmp (entry->match, email[1])) { 
+				if (!g_ascii_strcasecmp (entry->match, email[index])) { 
 					e_gw_connection_remove_junk_entry (cnc, entry->id);
 				}
 				list = list->next;
@@ -643,6 +660,9 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 	}
 	CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
 
+	if (folder->folder_flags & CAMEL_FOLDER_HAS_BEEN_DELETED)
+		return ;
+
 	count = camel_folder_summary_count (folder->summary);
 	CAMEL_GROUPWISE_FOLDER_REC_LOCK (folder, cache_lock);
 	for (i=0 ; i < count ; i++) {
@@ -655,6 +675,11 @@ groupwise_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 			continue;
 		flags = camel_message_info_flags (info);	
 
+		if (!(flags & CAMEL_MESSAGE_FOLDER_FLAGGED)) {
+				camel_message_info_free(info);
+				continue;
+		}
+
 		if ((flags & CAMEL_MESSAGE_JUNK) && strcmp(camel_folder_get_name(folder), JUNK_FOLDER)) { 
 			/*marked a message junk*/
 			move_to_junk (folder, info, ex);
@@ -913,7 +938,13 @@ update_update (CamelSession *session, CamelSessionThreadMsg *msg)
 	done = FALSE;
 	m->slist = NULL;
 
-	while (!done && !camel_application_is_exiting) {
+	while (!done) {
+
+		if (camel_application_is_exiting) {
+				CAMEL_SERVICE_REC_UNLOCK (gw_store, connect_lock);
+				return ;
+		}
+
 		item_list = NULL;
 		status = e_gw_connection_get_all_mail_uids (m->cnc, m->container_id, cursor, FALSE, READ_CURSOR_MAX_IDS, position, &item_list);
 		if (status != E_GW_CONNECTION_STATUS_OK) {
@@ -1047,6 +1078,7 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 	char *time_string = NULL, *t_str = NULL;
 	struct _folder_update_msg *msg;
 	gboolean check_all = FALSE;
+	int new_items = 0;
 
 	/* Sync-up the (un)read changes before getting updates,
 	so that the getFolderList will reflect the most recent changes too */
@@ -1141,7 +1173,7 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 		   for ( sl = slist ; sl != NULL; sl = sl->next) 
 		   list = g_list_append (list, sl->data);*/
 
-		if (slist && g_slist_length(slist) != 0)
+		if (slist && (new_items = g_slist_length(slist)) != 0)
 			check_all = TRUE;
 
 		g_slist_free (slist);
@@ -1182,6 +1214,33 @@ groupwise_refresh_folder(CamelFolder *folder, CamelException *ex)
 		if (gw_store->current_folder != folder) {
 			gw_store->current_folder = folder;
 		}
+		
+		if (check_all && !is_proxy) {
+				EGwContainer *container;
+				int i=0;
+
+				do {
+						/* HACK: Refer to Novell bugzilla bug #464379 */ 
+						container = e_gw_connection_get_container (cnc, container_id);
+						++i;
+						if (!strcmp (folder->full_name, e_gw_container_get_name (container))) 
+								i = 10;
+				} while (i < 2);
+
+				if (i == 10) {
+						/* HACK: Refer to Novell bugzilla bug #464379 */ 
+						d(printf ("Evolution's folder summary length is : %u\tserver has %u items",
+												camel_folder_summary_count (folder->summary), e_gw_container_get_total_count (container)));
+
+						if ((camel_folder_summary_count (folder->summary) + new_items) == e_gw_container_get_total_count (container))
+								check_all = FALSE;
+
+						folder->summary->unread_count = e_gw_container_get_unread_count (container);
+						folder->summary->visible_count = e_gw_container_get_total_count (container);
+				} else
+					check_all = FALSE;
+				g_object_unref (container);
+		}
 
 		if (list) {
 			gw_update_cache (folder, list, ex, FALSE);
@@ -1247,6 +1306,10 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 
 	gboolean is_proxy = folder->parent_store->flags & CAMEL_STORE_WRITE;
 
+	int folder_needs_caching;
+
+	camel_object_get (folder, NULL, CAMEL_OFFLINE_FOLDER_SYNC_OFFLINE, &folder_needs_caching, NULL);
+
 	changes = camel_folder_change_info_new ();
 	container_id = g_strdup (camel_groupwise_store_container_id_lookup (gw_store, folder->full_name));
 	if (!container_id) {
@@ -1285,7 +1348,11 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 
 		camel_operation_progress (NULL, (100*i)/total_items);
 
-		status = e_gw_connection_get_item (cnc, container_id, id, "peek default distribution recipient message attachments subject notification created recipientStatus status hasAttachment size recurrenceKey", &item);
+		if (folder_needs_caching)
+			status = e_gw_connection_get_item (cnc, container_id, id, GET_ITEM_VIEW_WITH_CACHE, &item);
+		else
+			status = e_gw_connection_get_item (cnc, container_id, id, GET_ITEM_VIEW_WITHOUT_CACHE, &item);
+
 		if (status != E_GW_CONNECTION_STATUS_OK) {
 			i++;
 			continue;
@@ -1313,6 +1380,7 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 				mi->info.content = camel_folder_summary_content_info_new (folder->summary);
 				mi->info.content->type = camel_content_type_new ("multipart", "mixed");	
 			}
+			mi->info.flags = 0;
 		}
 		
 		rk = e_gw_item_get_recurrence_key (item);
@@ -1327,16 +1395,12 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 
 		item_status = e_gw_item_get_item_status (item);
 		if (item_status & E_GW_ITEM_STAT_READ)
-			status_flags |= CAMEL_MESSAGE_SEEN;
+			mi->info.flags |= CAMEL_MESSAGE_SEEN;
 		else 
 			mi->info.flags &= ~CAMEL_MESSAGE_SEEN;
 
 		if (item_status & E_GW_ITEM_STAT_REPLIED)
-			status_flags |= CAMEL_MESSAGE_ANSWERED;
-		if (exists) 
-			mi->info.flags |= status_flags;
-		else 
-			mi->info.flags = status_flags;
+			mi->info.flags |= CAMEL_MESSAGE_ANSWERED;
 
 		priority = e_gw_item_get_priority (item);
 		if (priority && !(g_ascii_strcasecmp (priority,"High"))) {
@@ -1351,33 +1415,33 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 		mi->server_flags = mi->info.flags;
 
 		org = e_gw_item_get_organizer (item); 
+
 		if (org) {
-			GString *str;
-			int i;
-			str = g_string_new ("");
-			if (org->display_name && org->display_name[0] && org->email != NULL && org->email[0] != '\0') {
-				for (i = 0; org->display_name[i] != '<' && 
-						org->display_name[i] != '\0';
-						i++);
+				GString *str;
+				int i;
+				str = g_string_new ("");
 
-				org->display_name[i] = '\0';
-				str = g_string_append (str, org->display_name);
-				str = g_string_append (str, " ");
-			}
+				if (org->display_name && org->display_name[0] && org->email != NULL && org->email[0] != '\0') {
+						for (i = 0; org->display_name[i] != '<' && 
+										org->display_name[i] != '\0'; 
+										i++);
 
-                        if (org->display_name[0] == '\0') { 
+						org->display_name[i] = '\0';
+						str = g_string_append (str, org->display_name);
+						str = g_string_append (str, " ");
+				}
 
-				str = g_string_append (str, org->email);
-				str = g_string_append (str, " ");
-			}
-			if (org->email && org->email[0]) { 
-				g_string_append (str, "<");
-				str = g_string_append (str, org->email);
-				g_string_append (str, ">");
-			}
-			mi->info.from = camel_pstring_strdup (str->str);
-			g_string_free (str, TRUE);
+				if (org->email && org->email[0]) { 
+						g_string_append (str, "<");
+						str = g_string_append (str, org->email);
+						g_string_append (str, ">");
+				}
+
+
+				mi->info.from = camel_pstring_strdup (str->str);
+				g_string_free (str, TRUE);
 		}
+
 		g_string_truncate (str, 0);
 		recp_list = e_gw_item_get_recipient_list (item);
 		if (recp_list) {
@@ -1417,22 +1481,25 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 				time_t time;
 				time_t actual_time;
 				temp_date = e_gw_item_get_creation_date (item);
-				time = e_gw_connection_get_date_from_string (temp_date);
-				actual_time = camel_header_decode_date (ctime(&time), NULL);
+				if (temp_date) {
+						/* Creation date can be returned as null for auto-generated meetings */
+						time = e_gw_connection_get_date_from_string (temp_date);
+						actual_time = camel_header_decode_date (ctime(&time), NULL);
+				} else
+					actual_time = (time_t) 0;
 				mi->info.date_sent = mi->info.date_received = actual_time;
 			}
 		}
 
-		if (!exists) {
-			mi->info.uid = camel_pstring_strdup (e_gw_item_get_id(item));
-			mi->info.size = e_gw_item_get_mail_size (item);	
-			mi->info.subject = camel_pstring_strdup(e_gw_item_get_subject(item));
-		}
-
+		mi->info.dirty = TRUE;
 		if (exists) {
 			camel_folder_change_info_change_uid (changes, mi->info.uid);
 			camel_message_info_free (pmi);
 		} else {
+			mi->info.uid = camel_pstring_strdup (e_gw_item_get_id(item));
+			mi->info.size = e_gw_item_get_mail_size (item);	
+			mi->info.subject = camel_pstring_strdup(e_gw_item_get_subject(item));
+			
 			camel_folder_summary_add (folder->summary,(CamelMessageInfo *)mi);
 			camel_folder_change_info_add_uid (changes, mi->info.uid);
 			camel_folder_change_info_recent_uid (changes, mi->info.uid);
@@ -1442,27 +1509,30 @@ gw_update_cache (CamelFolder *folder, GList *list, CamelException *ex, gboolean
 		if (!strcmp (folder->full_name, "Junk Mail"))
 			continue;
 
-		/******************** Begine Caching ************************/
-		/* add to cache if its a new message*/
-		t_cache_stream  = camel_data_cache_get (gw_folder->cache, "cache", id, ex);
-		if (t_cache_stream) {
-			camel_object_unref (t_cache_stream);
+		if (folder_needs_caching) {
+				/******************** Begine Caching ************************/
+				/* add to cache if its a new message*/
+				t_cache_stream  = camel_data_cache_get (gw_folder->cache, "cache", id, ex);
+				if (t_cache_stream) {
+						camel_object_unref (t_cache_stream);
 
-			mail_msg = groupwise_folder_item_to_msg (folder, item, ex);
-			if (mail_msg)
-				camel_medium_set_header (CAMEL_MEDIUM (mail_msg), "X-Evolution-Source", groupwise_base_url_lookup (priv));
+						mail_msg = groupwise_folder_item_to_msg (folder, item, ex);
+						if (mail_msg)
+								camel_medium_set_header (CAMEL_MEDIUM (mail_msg), "X-Evolution-Source", groupwise_base_url_lookup (priv));
 
-			CAMEL_GROUPWISE_FOLDER_REC_LOCK (folder, cache_lock);
-			if ((cache_stream = camel_data_cache_add (gw_folder->cache, "cache", id, NULL))) {
-				if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) mail_msg, 	cache_stream) == -1 || camel_stream_flush (cache_stream) == -1)
-					camel_data_cache_remove (gw_folder->cache, "cache", id, NULL);
-				camel_object_unref (cache_stream);
-			}
+						CAMEL_GROUPWISE_FOLDER_REC_LOCK (folder, cache_lock);
+						if ((cache_stream = camel_data_cache_add (gw_folder->cache, "cache", id, NULL))) {
+								if (camel_data_wrapper_write_to_stream ((CamelDataWrapper *) mail_msg, 	cache_stream) == -1 || camel_stream_flush (cache_stream) == -1)
+										camel_data_cache_remove (gw_folder->cache, "cache", id, NULL);
+								camel_object_unref (cache_stream);
+						}
 
-			camel_object_unref (mail_msg);
-			CAMEL_GROUPWISE_FOLDER_REC_UNLOCK (folder, cache_lock);
+						camel_object_unref (mail_msg);
+						CAMEL_GROUPWISE_FOLDER_REC_UNLOCK (folder, cache_lock);
+				}
+				/******************** Caching stuff ends *************************/
 		}
-		/******************** Caching stuff ends *************************/
+
 		i++;
 		g_object_unref (item);
 	}
@@ -1629,8 +1699,11 @@ gw_update_summary ( CamelFolder *folder, GList *list,CamelException *ex)
 				time_t time;
 				time_t actual_time;
 				temp_date = e_gw_item_get_creation_date (item);
-				time = e_gw_connection_get_date_from_string (temp_date);
-				actual_time = camel_header_decode_date (ctime(&time), NULL);
+				if (temp_date) {
+						time = e_gw_connection_get_date_from_string (temp_date);
+						actual_time = camel_header_decode_date (ctime(&time), NULL);
+				} else
+						actual_time = (time_t) 0;
 				mi->info.date_sent = mi->info.date_received = actual_time;
 			}
 		}
@@ -1739,7 +1812,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 									gsize len_iter = 0;
 									char *temp = NULL;
 	
-									temp = g_base64_decode(t_attach, &len_iter);
+									temp = (char *) g_base64_decode(t_attach, &len_iter);
 									gstr = g_string_append_len (gstr, temp, len_iter);
 									g_free (temp);
 									len += len_iter;
@@ -1883,7 +1956,7 @@ groupwise_folder_item_to_msg( CamelFolder *folder,
 								gsize len_iter = 0;
 								char *temp = NULL;
 
-								temp = g_base64_decode(t_attach, &len_iter);
+								temp = (char *) g_base64_decode(t_attach, &len_iter);
 								gstr = g_string_append_len (gstr, temp, len_iter);
 								g_free (temp);
 								len += len_iter;
@@ -2130,6 +2203,12 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 	EGwConnectionStatus status = E_GW_CONNECTION_STATUS_OK;
 	EGwConnection *cnc;
 	CamelFolderChangeInfo *changes = NULL;
+	gboolean destination_is_trash;
+
+	if (destination == camel_store_get_trash (source->parent_store, NULL))
+		destination_is_trash = TRUE;
+	else
+		destination_is_trash = FALSE;
 
 	count = camel_folder_summary_count (destination->summary);
 	qsort (uids->pdata, uids->len, sizeof (void *), uid_compar);
@@ -2157,6 +2236,9 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 		GList *l;
 		int i;
 
+		if (destination_is_trash)
+			delete_originals = TRUE;
+
 		for (l = item_ids, i = 0; l; l = l->next, i++) {
 			CamelMessageInfo *info;
 
@@ -2247,33 +2329,45 @@ groupwise_transfer_messages_to (CamelFolder *source, GPtrArray *uids,
 			}
 		}
 
-		if (delete_originals) {
-			if (strcmp(source->full_name, "Sent Items")) {
-				status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
-						dest_container_id, source_container_id);
-			} else {
-				char *container_id = NULL;
-				container_id = e_gw_connection_get_container_id (cnc, "Mailbox");
-				status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
-						dest_container_id, container_id);
-				g_free (container_id);
-			}
 
-		} else
-			status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
-					dest_container_id, NULL);
-
-		if (status == E_GW_CONNECTION_STATUS_OK) {
-			if (delete_originals) { 
-				/*if ( !strcmp(source->full_name, SENT) ) {
-					camel_folder_delete_message(source, uids->pdata[index]);
-				} else {*/
-					camel_folder_summary_remove_uid (source->summary, uids->pdata[index]);
-					camel_folder_change_info_remove_uid (changes, uids->pdata[index]);
-				//}
-			}
+		if (destination_is_trash) {
+				e_gw_connection_remove_item (cnc, source_container_id, (const char*) uids->pdata[index]);
+				camel_folder_summary_remove_uid (source->summary, uids->pdata[index]);
+				camel_folder_change_info_remove_uid (changes, uids->pdata[index]);
 		} else {
-			g_warning ("Warning!! Could not move item : %s\n", (char *)uids->pdata[index]);
+				if (delete_originals) {
+						if (strcmp(source->full_name, "Sent Items")) {
+								status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
+												dest_container_id, source_container_id);
+						} else {
+								char *container_id = NULL;
+								container_id = e_gw_connection_get_container_id (cnc, "Mailbox");
+								status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
+												dest_container_id, container_id);
+								g_free (container_id);
+						}
+
+				} else
+						status = e_gw_connection_move_item (cnc, (const char *)uids->pdata[index],
+										dest_container_id, NULL);
+
+				if (status == E_GW_CONNECTION_STATUS_OK) {
+						if (delete_originals) { 
+								/*if ( !strcmp(source->full_name, SENT) ) {
+								  camel_folder_delete_message(source, uids->pdata[index]);
+								  } else {*/
+
+								if (!(gw_info->info.flags & CAMEL_MESSAGE_SEEN))
+										source->summary->unread_count --;
+
+								camel_folder_summary_remove_uid (source->summary, uids->pdata[index]);
+								camel_folder_change_info_remove_uid (changes, uids->pdata[index]);
+								//}
+						}
+				} else {
+						g_warning ("Warning!! Could not move item : %s\n", (char *)uids->pdata[index]);
+				}
+
 		}
 		index ++;
 	}
@@ -2629,7 +2723,21 @@ convert_to_task (EGwItem *item, char **str, int *len)
 	g_string_append_printf (gstr, "UID:%s\n",e_gw_item_get_icalid (item));
 	g_string_append_printf (gstr, "DTSTART:%s\n",e_gw_item_get_start_date (item));
 	g_string_append_printf (gstr, "SUMMARY:%s\n", e_gw_item_get_subject (item));
-	g_string_append_printf (gstr, "DESCRIPTION:%s\n", e_gw_item_get_message (item));
+
+	temp = e_gw_item_get_message (item);
+	if (temp) {
+		g_string_append(gstr, "DESCRIPTION:");
+		while (*temp) {
+			if (*temp == '\n')
+				g_string_append(gstr, "\\n");
+			else
+				g_string_append_c(gstr, *temp);
+			temp++;
+		}
+		g_string_append(gstr, "\n");	
+	}
+	temp = NULL;
+
 	g_string_append_printf (gstr, "DTSTAMP:%s\n", e_gw_item_get_creation_date (item));
 	g_string_append_printf (gstr, "X-GWMESSAGEID:%s\n", e_gw_item_get_id (item));
 	g_string_append_printf (gstr, "X-GWSHOW-AS:BUSY\n");
@@ -2684,6 +2792,7 @@ convert_to_note (EGwItem *item, char **str, int *len)
 	EGwItemOrganizer *org = NULL;
 	GString *gstr = g_string_new (NULL);
 	char **tmp = NULL;
+	const char *temp = NULL;
 
 	tmp = g_strsplit (e_gw_item_get_id (item), "@", -1);
 
@@ -2693,7 +2802,21 @@ convert_to_note (EGwItem *item, char **str, int *len)
 	g_string_append_printf (gstr, "UID:%s\n",e_gw_item_get_icalid (item));
 	g_string_append_printf (gstr, "DTSTART:%s\n",e_gw_item_get_start_date (item));
 	g_string_append_printf (gstr, "SUMMARY:%s\n", e_gw_item_get_subject (item));
-	g_string_append_printf (gstr, "DESCRIPTION:%s\n", e_gw_item_get_message (item));
+
+	temp = e_gw_item_get_message (item);
+	if (temp) {
+		g_string_append(gstr, "DESCRIPTION:");
+		while (*temp) {
+			if (*temp == '\n')
+				g_string_append(gstr, "\\n");
+			else
+				g_string_append_c(gstr, *temp);
+			temp++;
+		}
+		g_string_append(gstr, "\n");	
+	}
+	temp = NULL;
+
 	g_string_append_printf (gstr, "DTSTAMP:%s\n", e_gw_item_get_creation_date (item));
 	g_string_append_printf (gstr, "X-GWMESSAGEID:%s\n", e_gw_item_get_id (item));
 	g_string_append_printf (gstr, "X-GWRECORDID:%s\n", tmp[0]);
